==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CampaignManagementService/KeywordBid.pm <==
package Microsoft::AdCenter::V7::CampaignManagementService::KeywordBid;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V7::CampaignManagementService::KeywordBid - Represents "KeywordBid" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'KeywordBid';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    BroadMatchBid
    ExactMatchBid
    Keyword
    PhraseMatchBid
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    BroadMatchBid => 'double',
    ExactMatchBid => 'double',
    Keyword => 'string',
    PhraseMatchBid => 'double',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    BroadMatchBid => 0,
    ExactMatchBid => 0,
    Keyword => 1,
    PhraseMatchBid => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 BroadMatchBid

Gets/sets BroadMatchBid (double)

=head2 ExactMatchBid

Gets/sets ExactMatchBid (double)

=head2 Keyword

Gets/sets Keyword (string)

=head2 PhraseMatchBid

Gets/sets PhraseMatchBid (double)

=cut

==> Microsoft-AdCenter-8.03.tar.gz: Microsoft-AdCenter-8.03/lib/Microsoft/AdCenter/V7/CampaignManagementService/KeywordBid.pm <==
package Microsoft::AdCenter::V7::CampaignManagementService::KeywordBid;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V7::CampaignManagementService::KeywordBid - Represents "KeywordBid" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'KeywordBid';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    BroadMatchBid
    ExactMatchBid
    Keyword
    PhraseMatchBid
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    BroadMatchBid => 'double',
    ExactMatchBid => 'double',
    Keyword => 'string',
    PhraseMatchBid => 'double',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    BroadMatchBid => 0,
    ExactMatchBid => 0,
    Keyword => 1,
    PhraseMatchBid => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 BroadMatchBid

Gets/sets BroadMatchBid (double)

=head2 ExactMatchBid

Gets/sets ExactMatchBid (double)

=head2 Keyword

Gets/sets Keyword (string)

=head2 PhraseMatchBid

Gets/sets PhraseMatchBid (double)

=cut
